from setuptools import setup

setup(name='lazybones',
	version='0.12',
	description='Tool for scaffolding projects in a variety of languages',
	url='https://github.com/jacobmilligan/Lazybones.git',
	download_url='https://github.com/jacobmilligan/Lazybones/tarball/0.1',
	author='Jacob Milligan',
	license='LICENSE',
	packages=['lazybones'],
	zip_safe=False)
